==> abinit_9.6.2.orig.tar.gz: abinit-9.6.2/tests/tutorial/__init__.py <==
#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

subsuites = [
"base1",
"base2",
"base3",
"base4",
"basepar",
"bs",
"gw1",
"gw2",
"dftu",
"nuc",
"paw1",
"paw2",
"positron",
"spin",
"tddft",
"udet",
"fold2bloch",
]

#: List of input files
inp_files = [
"tbase1_1.abi", 
"tbase1_2.abi",
"tbase1_3.abi",
"tbase1_4.abi",
"tbase1_5.abi",
"tbase2_1.abi",
"tbase2_2.abi",
"tbase2_3.abi",
"tbase2_4.abi",
"tbase2_5.abi",
"tbase3_1.abi",
"tbase3_2.abi",
"tbase3_3.abi",
"tbase3_4.abi",
"tbase3_5.abi",
"tbase4_1.abi",
"tbase4_2.abi",
"tbase4_3.abi",
"tbase4_4.abi",
"tbase4_5.abi",
"tbase4_6.abi",
"tbase4_7.abi",
"tbase4_8.abi",
"tbasepar_1.abi",
"tbasepar_2.abi",
"tbs_1.abi",
"tbs_2.abi",
"tbs_3.abi",
"tbs_4.abi",
#"tbs_5.abi",  # Template file (not used)
"tdftu_1.abi",
"tdftu_2.abi",
"tdftu_3.abi",
"tdftu_4.abi",
"tgw1_1.abi",
"tgw1_2.abi",
"tgw1_3.abi",
"tgw1_4.abi",
"tgw1_5.abi",
"tgw1_6.abi",
"tgw2_1.abi",
"tgw2_2.abi",
"tgw2_3.abi",
"tgw2_4.abi",
"tnuc_1.abi",
"tnuc_2.abi",
"tnuc_3.abi",
"tpaw1_1.abi",
"tpaw1_2.abi",
"tpaw1_3.abi",
"tpaw1_4.abi",
"tpaw1_5.abi",
"tpaw2_1.abi",
"tpaw2_2.abi",
"tpositron_1.abi",
"tpositron_2.abi",
"tpositron_3.abi",
"tpositron_4.abi",
"tpositron_5.abi",
"tpositron_6.abi",
"tpositron_7.abi",
"tspin_1.abi",
"tspin_2.abi",
"tspin_3.abi",
"tspin_5.abi",
"tspin_6.abi",
"ttddft_1.abi",
"tudet_1.abi",
"tudet_2.abi",
"tudet_3.abi",
"tfold2bloch_1.abi",
"tfold2bloch_2.abi",
]

==> abinit_9.10.4.orig.tar.gz: abinit-9.10.4/tests/tutorial/__init__.py <==
#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

subsuites = [
"base1",
"base2",
"base3",
"base4",
"basepar",
"bs",
"gw1",
"gw2",
"dftu",
"lwf",
"nuc",
"paw1",
"paw2",
"positron",
"spin",
"tddft",
"udet",
"lruj",
"fold2bloch",
]

#: List of input files
inp_files = [
"tbase1_1.abi", 
"tbase1_2.abi",
"tbase1_3.abi",
"tbase1_4.abi",
"tbase1_5.abi",
"tbase2_1.abi",
"tbase2_2.abi",
"tbase2_3.abi",
"tbase2_4.abi",
"tbase2_5.abi",
"tbase3_1.abi",
"tbase3_2.abi",
"tbase3_3.abi",
"tbase3_4.abi",
"tbase3_5.abi",
"tbase4_1.abi",
"tbase4_2.abi",
"tbase4_3.abi",
"tbase4_4.abi",
"tbase4_5.abi",
"tbase4_6.abi",
"tbase4_7.abi",
"tbase4_8.abi",
"tbasepar_1.abi",
"tbasepar_2.abi",
"tbs_1.abi",
"tbs_2.abi",
"tbs_3.abi",
"tbs_4.abi",
#"tbs_5.abi",  # Template file (not used)
"tdftu_1.abi",
"tdftu_2.abi",
"tdftu_3.abi",
"tdftu_4.abi",
"tgw1_1.abi",
"tgw1_2.abi",
"tgw1_3.abi",
"tgw1_4.abi",
"tgw1_5.abi",
"tgw1_6.abi",
"tgw2_1.abi",
"tgw2_2.abi",
"tgw2_3.abi",
"tgw2_4.abi",
"tlwf_1.abi",
"tnuc_1.abi",
"tnuc_2.abi",
"tnuc_3.abi",
"tnuc_4.abi",
"tpaw1_1.abi",
"tpaw1_2.abi",
"tpaw1_3.abi",
"tpaw1_4.abi",
"tpaw1_5.abi",
"tpaw2_1.abi",
"tpaw2_2.abi",
"tpositron_1.abi",
"tpositron_2.abi",
"tpositron_3.abi",
"tpositron_4.abi",
"tpositron_5.abi",
"tpositron_6.abi",
"tpositron_7.abi",
"tspin_1.abi",
"tspin_2.abi",
"tspin_3.abi",
"tspin_5.abi",
"tspin_6.abi",
"ttddft_1.abi",
"tlruj_1.abi",
"tlruj_2.abi",
"tlruj_3.abi",
"tfold2bloch_1.abi",
"tfold2bloch_2.abi",
]
